AnnotationInfo class
The result of extracting an intention annotation from a class element.
- Annotations
-
- @model
Constructors
- AnnotationInfo({required Intention intention, String? owner})
-
Creates an annotation info.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- intention → Intention
-
The architectural intention declared on the class.
final
- owner → String?
-
The owner class name, if this is a
@PartOfannotation.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited