ClassCollector class
Collects all annotated classes from a package and its dependencies.
Wraps an AnalyzerAdapter to discover annotated classes by running the Dart analyzer.
- Annotations
-
- @dataSource
Constructors
- ClassCollector(AnalyzerAdapter analyzer, ResourceProvider resourceProvider)
-
Creates a collector using
analyzerfor running the Dart analyzer.const
Properties
- analyzer → AnalyzerAdapter
-
The analyzer adapter that performs the actual analysis.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- resourceProvider → ResourceProvider
-
File system abstraction for checking directory existence.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
collect(
String packageRoot) → Future< CollectionResult> -
Scans all
.dartfiles inlib/and walks transitive imports to discover annotated classes in dependency packages. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited